@@ -184,7 +184,7 @@ class Band:
             for j in range(nbands):
                 band = f'band{j+1}'
                 for atom in range(natoms):
-                    orbital_weights = projected_eigenvalues[i][j][atom]
+                    orbital_weights = projected_eigenvalues[i][j][atom] ** 2
                     projected_dict[band][atom] = np.vstack([
                         projected_dict[band][atom],
                         orbital_weights
@@ -343,6 +343,7 @@ class Band:
             band_df = pd.DataFrame()
             for element in elements:
                 element_index = np.where(element_list == element)[0]
+                nb_atoms = len(element_index)
                 df = pd.concat(
                     [projected_dict[band][i] for i in element_index],
                     axis=1
@@ -370,7 +371,8 @@ class Band:
                             element_dict[band][element] = element_dict[band][element].drop(
                                 columns=range(9))
                 else:
-                    element_dict[band][element] = df.sum(axis=1).tolist()
+                    norm_df = df.sum(axis=1)
+                    element_dict[band][element] = norm_df.tolist()
 
         return element_dict
 
@@ -384,7 +386,7 @@ class Band:
         """
 
         high_sym_points = self.kpoints.kpts
-        kpts_labels = np.array([f'${k}$' for k in self.kpoints.labels])
+        kpts_labels = np.array([f'${k}$' if k != 'G' else '$\\Gamma$' for k in self.kpoints.labels])
         all_kpoints = self.vasprun.actual_kpoints
 
         index = [0]
@@ -416,8 +418,7 @@ class Band:
         kpoints_index.append(n*(len(kpath) - 1)-1)
         kpoints_index.insert(0, 0)
 
-        kpath = [f'${k}$' if k !=
-                 'G' else '$\\Gamma$' for k in kpath.upper().strip()]
+        kpath = [f'${k}$' if k != 'G' else '$\\Gamma$' for k in kpath.upper().strip()]
 
         for i in range(len(kpoints_index)):
             if 0 < i < len(kpoints_index) - 1:
@@ -480,6 +481,7 @@ class Band:
             linewidth (float): Line width of the plain band structure plotted in the background
             band_color (string): Color of the plain band structure
         """
+        scale_factor = scale_factor ** 1.5
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
 
@@ -571,6 +573,7 @@ class Band:
             linewidth (float): Line width of the plain band structure plotted in the background
             band_color (string): Color of the plain band structure
         """
+        scale_factor = scale_factor ** 1.5
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
 
@@ -660,6 +663,7 @@ class Band:
             linewidth (float): Line width of the plain band structure plotted in the background
             band_color (string): Color of the plain band structure
         """
+        scale_factor = scale_factor ** 1.5
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
 
@@ -739,6 +743,7 @@ class Band:
             linewidth (float): Line width of the plain band structure plotted in the background
             band_color (string): Color of the plain band structure
         """
+        scale_factor = scale_factor ** 1.5
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
 
@@ -820,6 +825,7 @@ class Band:
             linewidth (float): Line width of the plain band structure plotted in the background
             band_color (string): Color of the plain band structure
         """
+        scale_factor = scale_factor ** 1.5
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
 
@@ -903,6 +909,7 @@ class Band:
             linewidth (float): line width of the plain band structure plotted in the background
             band_color (string): color of the plain band structure
         """
+        scale_factor = scale_factor ** 1.5
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
 
@@ -1001,6 +1008,7 @@ class Band:
             linewidth (float): Line width of the plain band structure plotted in the background
             band_color (string): Color of the plain band structure
         """
+        scale_factor = scale_factor ** 1.5
 
         self.plot_plain(ax=ax, linewidth=linewidth, color=band_color)
 
